description
======
------
套娃之神mumuzi，在misc题基础上创造性地融入了围棋和套娃元素，开创了musc新分类，他出的题被亲切地称为“一题顶过去五题”，做完之后腰酸了，背疼了，跳楼也有劲了。


更新记录
=======
-------
v0.0.1 beta版本。

v0.1.0 更新txt文档的套娃功能。

v0.1.1 更新套神必须先说话再套娃的功能。

v0.1.2 更新套神语录。

v0.1.3 更新txt文档的解套功能；更新压缩文件的加套功能；拆分套神语录。

v0.1.4 更新txt文档的加套解套功能，去除效率极低的base92和hex。

v1.0.0 更新套神说话时添加分隔符；更新了套题算法并去掉了效率低下的套题算法。删除了不能解题的解题功能，目前正式发布mumuzi的套娃姬版本，版本号为v1.0.0。

v1.0.1 更新zip加密算法；添加了套神口算md5的技能。

v1.0.2 更新了help()函数，现在可以用mumuzi.help()来查看功能了。修复套娃函数只能套一层的奇怪bug。